Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9181)

Unified Diff: chrome/browser/ui/views/global_error_bubble_view.cc

Issue 8870003: Merge BorderContentsView into BubbleFrameView; simplify. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync and merge. Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/views/first_run_bubble.cc ('k') | chrome/browser/ui/views/page_info_bubble_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/views/global_error_bubble_view.cc
diff --git a/chrome/browser/ui/views/global_error_bubble_view.cc b/chrome/browser/ui/views/global_error_bubble_view.cc
index f1735935e9b120e168f35752c2dc4f9f38724b6a..7f24036f4169597b9811f294ade76767daf90806 100644
--- a/chrome/browser/ui/views/global_error_bubble_view.cc
+++ b/chrome/browser/ui/views/global_error_bubble_view.cc
@@ -29,8 +29,8 @@ const int kMaxBubbleViewWidth = 262;
// The horizontal padding between the title and the icon.
const int kTitleHorizontalPadding = 3;
-// The vertical offset of the wrench bubble from the wrench menu button.
-const int kWrenchBubblePointOffsetY = -6;
+// The vertical inset of the wrench bubble anchor from the wrench menu button.
+const int kAnchorVerticalInset = 5;
const int kLayoutBottomPadding = 2;
@@ -125,7 +125,7 @@ GlobalErrorBubbleView::~GlobalErrorBubbleView() {
gfx::Rect GlobalErrorBubbleView::GetAnchorRect() {
gfx::Rect rect(views::BubbleDelegateView::GetAnchorRect());
- rect.Offset(0, anchor_view() ? kWrenchBubblePointOffsetY : 0);
+ rect.Inset(0, anchor_view() ? kAnchorVerticalInset : 0);
return rect;
}
« no previous file with comments | « chrome/browser/ui/views/first_run_bubble.cc ('k') | chrome/browser/ui/views/page_info_bubble_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698